# A simple implementation of unauthenticated ECDH

See [module](src/blindecdh/__init__.py) for documentation.

This package is distributed under the GNU Lesser General Public License v2.1.
For relicensing, contact the package author.
